@@ -37,8 +37,6 @@ from __future__ import unicode_literals
 import collections
 import copy
 import functools
-import inspect
-import itertools
 import json
 import sys
 
@@ -58,7 +56,7 @@ except ImportError:
 
 # Will be parsed by setup.py to determine package metadata
 __author__ = 'Stefan Kögl <stefan@skoegl.net>'
-__version__ = '1.20'
+__version__ = '1.23'
 __website__ = 'https://github.com/stefankoegl/python-json-patch'
 __license__ = 'Modified BSD License'
 
@@ -335,8 +333,14 @@ class PatchOperation(object):
     """A single operation inside a JSON Patch."""
 
     def __init__(self, operation):
-        self.location = operation['path']
-        self.pointer = JsonPointer(self.location)
+
+        if isinstance(operation['path'], JsonPointer):
+            self.location = operation['path'].path
+            self.pointer = operation['path']
+        else:
+            self.location = operation['path']
+            self.pointer = JsonPointer(self.location)
+
         self.operation = operation
 
     def apply(self, obj):
@@ -493,7 +497,10 @@ class MoveOperation(PatchOperation):
 
     def apply(self, obj):
         try:
-            from_ptr = JsonPointer(self.operation['from'])
+            if isinstance(self.operation['from'], JsonPointer):
+                from_ptr = self.operation['from']
+            else:
+                from_ptr = JsonPointer(self.operation['from'])
         except KeyError as ex:
             raise InvalidJsonPatch(
                 "The operation does not contain a 'from' member")
@@ -730,7 +737,6 @@ class DiffBuilder(object):
         new_op = RemoveOperation({
             'op': 'remove',
             'path': _path_join(path, key),
-            'value': item,
         })
         index = self.take_index(item, _ST_ADD)
         new_index = self.insert(new_op)
